@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.urls import reverse
 from django.utils.html import format_html
 from django_common_objects.admin import UserAdmin
 from django.db.models import Count
@@ -10,6 +11,8 @@ TaskScheduleLogModel = get_schedule_log_model()
 
 
 class TaskAdmin(UserAdmin):
+    schedule_model = models.TaskSchedule
+
     form = forms.TaskForm
     list_display = ('id', 'admin_parent', 'name', 'category', 'admin_status', 'schedules', 'update_time')
     fields = (
@@ -29,7 +32,9 @@ class TaskAdmin(UserAdmin):
 
     def admin_parent(self, obj):
         if obj.parent:
-            return format_html('<a href="/admin/task_schedule/task/%s/change/">%s</a>' % (obj.parent.id, obj.parent))
+            return format_html('<a href="/admin/%s/%s/%s/change/">%s</a>' % (
+                obj._meta.app_label, self.model._meta.model_name, obj.parent.id, obj.parent
+            ))
         return '-'
 
     admin_parent.short_description = '父任务'
@@ -43,15 +48,16 @@ class TaskAdmin(UserAdmin):
     def schedules(self, obj):
         schedules = self.extra_context['schedules'].get(obj.id, 0)
         if schedules:
-            return format_html('<a href="/admin/task_schedule/taskschedule/?task__id__exact=%s">查看(%s)</a>'
-                               % (obj.id, schedules))
+            return format_html('<a href="/admin/%s/%s/?task__id__exact=%s">查看(%s)</a>' % (
+                obj._meta.app_label, self.schedule_model._meta.model_name, obj.id, schedules
+            ))
         return '-'
 
     schedules.short_description = '任务计划'
 
     def changelist_view(self, request, extra_context=None):
         queryset = self.get_queryset(request)
-        schedules = models.TaskSchedule.objects.filter(task__in=queryset, ).values('task__id'
+        schedules = self.schedule_model.objects.filter(task__in=queryset, ).values('task__id'
                                                                                    ).annotate(Count('task__id'))
         self.extra_context['schedules'] = {x['task__id']: x['task__id__count'] for x in schedules}
         return super(TaskAdmin, self).changelist_view(request, extra_context=self.extra_context)
@@ -69,8 +75,11 @@ class TaskScheduleCallbackAdmin(UserAdmin):
 
 
 class TaskScheduleAdmin(UserAdmin):
+    task_model = TaskModel
+    schedule_log_model = TaskScheduleLogModel
+    schedule_put_name = 'task_schedule_put'
     list_display = ('id', 'admin_task', 'schedule_type', 'schedule_sub_type', 'next_schedule_time',
-                    'status', 'logs', 'update_time')
+                    'status', 'put', 'logs', 'update_time')
 
     # readonly_fields = ("next_schedule_time", )
 
@@ -95,11 +104,15 @@ class TaskScheduleAdmin(UserAdmin):
     form = forms.TaskScheduleForm
 
     def admin_task(self, obj):
-        return format_html('<a href="/admin/task_schedule/task/%s/change/">%s</a>' % (obj.task.id, obj.task.name))
+        return format_html('<a href="/admin/%s/%s/%s/change/">%s</a>' % (
+            obj._meta.app_label, self.task_model._meta.model_name, obj.task.id, obj.task.name
+        ))
     admin_task.short_description = '任务'
 
     def logs(self, obj):
-        return format_html('<a href="/admin/task_schedule/taskschedulelog/?schedule__id__exact=%s">查看</a>' % obj.id)
+        return format_html('<a href="/admin/%s/%s/?schedule__id__exact=%s">查看</a>' % (
+            obj._meta.app_label, self.schedule_log_model._meta.model_name, obj.id
+        ))
     logs.short_description = '日志'
 
     def schedule_type(self, obj):
@@ -109,7 +122,6 @@ class TaskScheduleAdmin(UserAdmin):
             if i == t:
                 return i.label
         return '-'
-
     schedule_type.short_description = '计划类型'
 
     def schedule_sub_type(self, obj: models.TaskSchedule):
@@ -123,9 +135,16 @@ class TaskScheduleAdmin(UserAdmin):
         elif schedule_type == TaskScheduleType.TIMINGS:
             return ScheduleTimingType[config[schedule_type]['type']].label
         return '-'
-
     schedule_sub_type.short_description = '详细'
 
+    def put(self, obj):
+        url = reverse(self.schedule_put_name, args=(obj.id,))
+        return format_html(
+            '<a href="%s" target="_blank">调度+1</a>' % url
+        )
+    put.allow_tags = True
+    put.short_description = '调度'
+
     class Media:
         js = (
             'https://cdn.bootcss.com/jquery/3.3.1/jquery.min.js',
@@ -142,11 +161,20 @@ class TaskScheduleAdmin(UserAdmin):
 
 
 class TaskScheduleLogAdmin(UserAdmin):
-    list_display = ('id', 'schedule', 'status', 'schedule_time', 'create_time')
+    schedule_retry_name = 'task_schedule_retry'
+    list_display = ('id', 'schedule', 'status', 'retry', 'schedule_time', 'create_time')
 
     def get_readonly_fields(self, request, obj=None):
         return [field.name for field in self.model._meta.fields]
 
+    def retry(self, obj):
+        url = reverse(self.schedule_retry_name, args=(obj.id,))
+        return format_html(
+            '<a href="%s" target="_blank">重试</a>' % url
+        )
+    retry.allow_tags = True
+    retry.short_description = '重试'
+
 
 admin.site.register(TaskModel, TaskAdmin)
 admin.site.register(models.TaskSchedule, TaskScheduleAdmin)
